package jalview.bin;

import java.util.Date;

import org.testng.Assert;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import jalview.gui.AlignFrame;
import jalview.gui.Desktop;
import jalview.gui.JvOptionPane;

@Test(singleThreaded = true)
public class CommandsTest
{
  @BeforeClass(alwaysRun = true)
  public static void setUpBeforeClass() throws Exception
  {
    Cache.loadProperties("test/jalview/gui/quitProps.jvprops");
    Date oneHourFromNow = new Date(
            System.currentTimeMillis() + 3600 * 1000);
    Cache.setDateProperty("JALVIEW_NEWS_RSS_LASTMODIFIED", oneHourFromNow);
  }

  @BeforeClass(alwaysRun = true)
  public void setUpJvOptionPane()
  {
    JvOptionPane.setInteractiveMode(false);
    JvOptionPane.setMockResponse(JvOptionPane.CANCEL_OPTION);
  }

  @Test(groups = "Functional", dataProvider = "cmdLines")
  public void commandsOpenTest(String cmdLine, String sequence)
  {
    String[] args = cmdLine.split("\\s+");
    Jalview.main(args);
    ArgParser argparser = new ArgParser(args);
    boolean commandsSuccess = Commands.processArgs(argparser, false);
    Assert.assertTrue(commandsSuccess, "Overall commandsSuccess is false");

    if (sequence != null)
    {
      AlignFrame[] afs = Desktop.getAlignFrames();
      boolean found = false;
      ALIGNFRAME: for (AlignFrame af : afs)
      {
        for (String name : af.getViewport().getAlignment()
                .getSequenceNames())
        {
          if (sequence.equals(name))
          {
            found = true;
            break ALIGNFRAME;
          }
        }
      }
      Assert.assertTrue(found, "Sequence '" + sequence
              + "' was not found in opened alignment files: " + cmdLine);
    }
  }

  @DataProvider(name = "cmdLines")
  public Object[][] cmdLines()
  {
    return new Object[][] { { "--open=examples/uniref50.fa", "FER1_SPIOL" },
        { "--argfile=test/jalview/bin/argparser/argfile0.txt", null } };
  }

}
